/****************************************************************************
** Meta object code from reading C++ file 'qbluetoothservicediscoveryagent.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtconnectivity/src/bluetooth/qbluetoothservicediscoveryagent.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qbluetoothservicediscoveryagent.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN31QBluetoothServiceDiscoveryAgentE_t {};
} // unnamed namespace

template <> constexpr inline auto QBluetoothServiceDiscoveryAgent::qt_create_metaobjectdata<qt_meta_tag_ZN31QBluetoothServiceDiscoveryAgentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QBluetoothServiceDiscoveryAgent",
        "serviceDiscovered",
        "",
        "QBluetoothServiceInfo",
        "info",
        "finished",
        "canceled",
        "errorOccurred",
        "QBluetoothServiceDiscoveryAgent::Error",
        "error",
        "start",
        "DiscoveryMode",
        "mode",
        "stop",
        "clear",
        "Error",
        "NoError",
        "InputOutputError",
        "PoweredOffError",
        "InvalidBluetoothAdapterError",
        "MissingPermissionsError",
        "UnknownError",
        "MinimalDiscovery",
        "FullDiscovery"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'serviceDiscovered'
        QtMocHelpers::SignalData<void(const QBluetoothServiceInfo &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canceled'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorOccurred'
        QtMocHelpers::SignalData<void(QBluetoothServiceDiscoveryAgent::Error)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<void(enum DiscoveryMode)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Error'
        QtMocHelpers::EnumData<enum Error>(15, 15, QMC::EnumFlags{}).add({
            {   16, Error::NoError },
            {   17, Error::InputOutputError },
            {   18, Error::PoweredOffError },
            {   19, Error::InvalidBluetoothAdapterError },
            {   20, Error::MissingPermissionsError },
            {   21, Error::UnknownError },
        }),
        // enum 'DiscoveryMode'
        QtMocHelpers::EnumData<enum DiscoveryMode>(11, 11, QMC::EnumFlags{}).add({
            {   22, DiscoveryMode::MinimalDiscovery },
            {   23, DiscoveryMode::FullDiscovery },
        }),
    };
    return QtMocHelpers::metaObjectData<QBluetoothServiceDiscoveryAgent, qt_meta_tag_ZN31QBluetoothServiceDiscoveryAgentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QBluetoothServiceDiscoveryAgent::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QBluetoothServiceDiscoveryAgentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QBluetoothServiceDiscoveryAgentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN31QBluetoothServiceDiscoveryAgentE_t>.metaTypes,
    nullptr
} };

void QBluetoothServiceDiscoveryAgent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QBluetoothServiceDiscoveryAgent *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->serviceDiscovered((*reinterpret_cast<std::add_pointer_t<QBluetoothServiceInfo>>(_a[1]))); break;
        case 1: _t->finished(); break;
        case 2: _t->canceled(); break;
        case 3: _t->errorOccurred((*reinterpret_cast<std::add_pointer_t<QBluetoothServiceDiscoveryAgent::Error>>(_a[1]))); break;
        case 4: _t->start((*reinterpret_cast<std::add_pointer_t<enum DiscoveryMode>>(_a[1]))); break;
        case 5: _t->start(); break;
        case 6: _t->stop(); break;
        case 7: _t->clear(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QBluetoothServiceInfo >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QBluetoothServiceDiscoveryAgent::*)(const QBluetoothServiceInfo & )>(_a, &QBluetoothServiceDiscoveryAgent::serviceDiscovered, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QBluetoothServiceDiscoveryAgent::*)()>(_a, &QBluetoothServiceDiscoveryAgent::finished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QBluetoothServiceDiscoveryAgent::*)()>(_a, &QBluetoothServiceDiscoveryAgent::canceled, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QBluetoothServiceDiscoveryAgent::*)(QBluetoothServiceDiscoveryAgent::Error )>(_a, &QBluetoothServiceDiscoveryAgent::errorOccurred, 3))
            return;
    }
}

const QMetaObject *QBluetoothServiceDiscoveryAgent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QBluetoothServiceDiscoveryAgent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QBluetoothServiceDiscoveryAgentE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QBluetoothServiceDiscoveryAgent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void QBluetoothServiceDiscoveryAgent::serviceDiscovered(const QBluetoothServiceInfo & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QBluetoothServiceDiscoveryAgent::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QBluetoothServiceDiscoveryAgent::canceled()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QBluetoothServiceDiscoveryAgent::errorOccurred(QBluetoothServiceDiscoveryAgent::Error _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
