/****************************************************************************
** Meta object code from reading C++ file 'propertiesadaptor_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtconnectivity/src/bluetooth/bluez/propertiesadaptor_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'propertiesadaptor_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18QtBluetoothPrivate35OrgFreedesktopDBusPropertiesAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto QtBluetoothPrivate::OrgFreedesktopDBusPropertiesAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN18QtBluetoothPrivate35OrgFreedesktopDBusPropertiesAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtBluetoothPrivate::OrgFreedesktopDBusPropertiesAdaptor",
        "D-Bus Interface",
        "org.freedesktop.DBus.Properties",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.DBus.Properties\">\n    <metho"
        "d name=\"Get\">\n      <arg direction=\"in\" type=\"s\" name=\"int"
        "erface\"/>\n      <arg direction=\"in\" type=\"s\" name=\"name\"/>"
        "\n      <arg direction=\"out\" type=\"v\" name=\"value\"/>\n    </"
        "method>\n    <method name=\"Set\">\n      <arg direction=\"in\" ty"
        "pe=\"s\" name=\"interface\"/>\n      <arg direction=\"in\" type=\""
        "s\" name=\"name\"/>\n      <arg direction=\"in\" type=\"v\" name=\""
        "value\"/>\n    </method>\n    <method name=\"GetAll\">\n      <arg"
        " direction=\"in\" type=\"s\" name=\"interface\"/>\n      <arg dire"
        "ction=\"out\" type=\"a{sv}\" name=\"properties\"/>\n      <annotat"
        "ion value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.O"
        "ut0\"/>\n    </method>\n    <signal name=\"PropertiesChanged\">\n "
        "     <arg type=\"s\" name=\"interface\"/>\n      <arg type=\"a{sv}"
        "\" name=\"changed_properties\"/>\n      <annotation value=\"QVaria"
        "ntMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out1\"/>\n      <ar"
        "g type=\"as\" name=\"invalidated_properties\"/>\n    </signal>\n  "
        "</interface>\n",
        "PropertiesChanged",
        "",
        "interface",
        "QVariantMap",
        "changed_properties",
        "invalidated_properties",
        "Get",
        "QDBusVariant",
        "name",
        "GetAll",
        "Set",
        "value"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'PropertiesChanged'
        QtMocHelpers::SignalData<void(const QString &, const QVariantMap &, const QStringList &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { 0x80000000 | 8, 9 }, { QMetaType::QStringList, 10 },
        }}),
        // Slot 'Get'
        QtMocHelpers::SlotData<QDBusVariant(const QString &, const QString &)>(11, 6, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'GetAll'
        QtMocHelpers::SlotData<QVariantMap(const QString &)>(14, 6, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'Set'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QDBusVariant &)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 13 }, { 0x80000000 | 12, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<OrgFreedesktopDBusPropertiesAdaptor, qt_meta_tag_ZN18QtBluetoothPrivate35OrgFreedesktopDBusPropertiesAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QtBluetoothPrivate::OrgFreedesktopDBusPropertiesAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QtBluetoothPrivate35OrgFreedesktopDBusPropertiesAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QtBluetoothPrivate35OrgFreedesktopDBusPropertiesAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18QtBluetoothPrivate35OrgFreedesktopDBusPropertiesAdaptorE_t>.metaTypes,
    nullptr
} };

void QtBluetoothPrivate::OrgFreedesktopDBusPropertiesAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopDBusPropertiesAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->PropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 1: { QDBusVariant _r = _t->Get((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusVariant*>(_a[0]) = std::move(_r); }  break;
        case 2: { QVariantMap _r = _t->GetAll((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->Set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusVariant >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopDBusPropertiesAdaptor::*)(const QString & , const QVariantMap & , const QStringList & )>(_a, &OrgFreedesktopDBusPropertiesAdaptor::PropertiesChanged, 0))
            return;
    }
}

const QMetaObject *QtBluetoothPrivate::OrgFreedesktopDBusPropertiesAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtBluetoothPrivate::OrgFreedesktopDBusPropertiesAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QtBluetoothPrivate35OrgFreedesktopDBusPropertiesAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int QtBluetoothPrivate::OrgFreedesktopDBusPropertiesAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void QtBluetoothPrivate::OrgFreedesktopDBusPropertiesAdaptor::PropertiesChanged(const QString & _t1, const QVariantMap & _t2, const QStringList & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
